#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   taffybar
version:                4.1.0
visibility:             public
id:                     taffybar-4.1.0-B8RMwXYabgTJIrANlcaFPo
key:                    taffybar-4.1.0-B8RMwXYabgTJIrANlcaFPo
license:                BSD-3-Clause
maintainer:             IvanMalison@gmail.com
author:                 Ivan Malison
homepage:               http://github.com/taffybar/taffybar
synopsis:               A desktop bar similar to xmobar, but with more GUI
category:               System
abi:                    9bb184830f5ec58267d8801d9db04f58
exposed:                True
exposed-modules:
    System.Taffybar System.Taffybar.Auth System.Taffybar.Context
    System.Taffybar.DBus System.Taffybar.DBus.Toggle
    System.Taffybar.Example System.Taffybar.Hooks
    System.Taffybar.Information.Battery System.Taffybar.Information.CPU
    System.Taffybar.Information.CPU2 System.Taffybar.Information.Chrome
    System.Taffybar.Information.Crypto
    System.Taffybar.Information.DiskIO
    System.Taffybar.Information.EWMHDesktopInfo
    System.Taffybar.Information.MPRIS2
    System.Taffybar.Information.Memory
    System.Taffybar.Information.Network
    System.Taffybar.Information.SafeX11
    System.Taffybar.Information.StreamInfo
    System.Taffybar.Information.X11DesktopInfo
    System.Taffybar.Information.XDG.Protocol
    System.Taffybar.LogFormatter System.Taffybar.SimpleConfig
    System.Taffybar.Support.PagerHints System.Taffybar.Util
    System.Taffybar.Widget System.Taffybar.Widget.Battery
    System.Taffybar.Widget.CPUMonitor
    System.Taffybar.Widget.CommandRunner System.Taffybar.Widget.Crypto
    System.Taffybar.Widget.DiskIOMonitor
    System.Taffybar.Widget.FSMonitor
    System.Taffybar.Widget.FreedesktopNotifications
    System.Taffybar.Widget.Generic.AutoSizeImage
    System.Taffybar.Widget.Generic.ChannelGraph
    System.Taffybar.Widget.Generic.ChannelWidget
    System.Taffybar.Widget.Generic.DynamicMenu
    System.Taffybar.Widget.Generic.Graph
    System.Taffybar.Widget.Generic.Icon
    System.Taffybar.Widget.Generic.PollingBar
    System.Taffybar.Widget.Generic.PollingGraph
    System.Taffybar.Widget.Generic.PollingLabel
    System.Taffybar.Widget.Generic.VerticalBar
    System.Taffybar.Widget.Layout System.Taffybar.Widget.MPRIS2
    System.Taffybar.Widget.NetworkGraph System.Taffybar.Widget.SNITray
    System.Taffybar.Widget.SimpleClock
    System.Taffybar.Widget.SimpleCommandButton
    System.Taffybar.Widget.Text.CPUMonitor
    System.Taffybar.Widget.Text.MemoryMonitor
    System.Taffybar.Widget.Text.NetworkMonitor
    System.Taffybar.Widget.Util System.Taffybar.Widget.Weather
    System.Taffybar.Widget.Windows System.Taffybar.Widget.Workspaces
    System.Taffybar.Widget.WttrIn System.Taffybar.Widget.XDGMenu.Menu
    System.Taffybar.Widget.XDGMenu.MenuWidget
    System.Taffybar.WindowIcon

hidden-modules:
    Paths_taffybar System.Taffybar.DBus.Client.MPRIS2
    System.Taffybar.DBus.Client.Params
    System.Taffybar.DBus.Client.UPower
    System.Taffybar.DBus.Client.UPowerDevice
    System.Taffybar.DBus.Client.Util

import-dirs:            /usr/lib/ghc-9.6.6/site-local/taffybar-4.1.0
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/taffybar-4.1.0 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/taffybar-4.1.0 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/taffybar
hs-libraries:           HStaffybar-4.1.0-B8RMwXYabgTJIrANlcaFPo
extra-libraries:
    gtk-3 gdk-3 pangocairo-1.0 cairo-gobject gdk_pixbuf-2.0 atk-1.0
    pango-1.0 cairo harfbuzz gio-2.0 gobject-2.0 glib-2.0 z

extra-libraries-static:
    gtk-3 gdk-3 pangocairo-1.0 m Xrandr Xcursor Xcomposite Xdamage
    Xinerama cloudproviders cairo-gobject m dl gdk_pixbuf-2.0 m
    glycin-2 seccomp lcms2 pthread atk-bridge-2.0 atspi Xtst Xi Xfixes
    atk-1.0 dbus-1 xkbcommon wayland-cursor wayland-egl wayland-client
    m rt epoxy dl GL EGL pangoft2-1.0 m pango-1.0 m fribidi thai datrie
    Xft cairo m dl fontconfig m expat m Xext Xrender X11 pthread
    xcb-render xcb-shm xcb Xau Xdmcp pixman-1 m harfbuzz-gobject
    harfbuzz m freetype dl bz2 png16 m m brotlidec brotlicommon
    graphite2 gio-2.0 gobject-2.0 ffi gmodule-2.0 glib-2.0 atomic m
    pcre2-8 pthread z mount blkid systemd sysprof-capture-4

include-dirs:
    /usr/include/gtk-3.0 /usr/include/pango-1.0 /usr/include
    /usr/include/cloudproviders /usr/include/cairo
    /usr/include/gdk-pixbuf-2.0 /usr/include/glycin-2
    /usr/include/at-spi2-atk/2.0 /usr/include/at-spi-2.0
    /usr/include/atk-1.0 /usr/include/dbus-1.0
    /usr/lib/dbus-1.0/include /usr/include/fribidi
    /usr/include/pixman-1 /usr/include/harfbuzz /usr/include/freetype2
    /usr/include/libpng16 /usr/include/gio-unix-2.0
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    HStringTemplate-0.8.8-FhA5LRbR4w12LsQBcgZC8c
    X11-1.10.3-4bnVd3SdcvsJN8LDt8CJay
    aeson-2.2.2.0-Bvq1RZLTB982HJyF7e96XU
    ansi-terminal-1.1-5nZVpYMolxlDp5iPgkZNkW base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-534uwm1BQ035a3x29nwuhR
    containers-0.6.7 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    dbus-1.3.3-B29sEISa9vRKO9bSWo5TvW
    dbus-hslogger-0.1.0.1-EFBxJoZgMclLMpKMOQrnjU directory-1.3.8.5
    dyre-0.9.2-7Le4jOC75atJ5aaluPymeQ
    either-5.0.3-4oon1pfjcei5YxwlRFwIb0
    enclosed-exceptions-1.0.3-FLamOXyB3cIVJSVSBeWq2 filepath-1.4.300.1
    fsnotify-0.4.4.0-6bPTrqD3dyFCbpeBwRBUHS
    gi-cairo-connector-0.1.1-DPJmyciB87XHvZ3u8yhYZr
    gi-cairo-render-0.1.2-2RE0dTa0lmd3SA0hreLAyc
    gi-gdk-3.0.29-DEgivCB0DaeL9IebClxuts
    gi-gdkpixbuf-2.0.32-COSHooAt1wu3WLcjSsHFM8
    gi-gdkx11-3.0.16-5gziLVnHzJcLL6sJwiLCAq
    gi-glib-2.0.30-6wM4fTS56ItEgss596PiDy
    gi-gtk-3.0.43-3RxB5kf0dau7fmCykPbh5S
    gi-gtk-hs-0.3.17-2wS8x7UzVu62Vl9cUbCoWS
    gi-pango-1.0.30-IoWMRGoLsfg6fFyw5QSfl8
    gtk-sni-tray-0.1.8.1-5dcKqpJHoE4H0qAi86ciCD
    gtk-strut-0.1.3.2-3VCdxKWHMrV5GeCSdeE9ll
    haskell-gi-base-0.26.9-DWjNTqMCnmO6mDRH5jgSPC
    hslogger-1.3.2.0-E6C8jEKjAdBKKjE0uqQrQ7
    http-client-0.7.19-BV4AT2QZinhAZt9DyDMIrY
    http-client-tls-0.3.6.4-4PkwIHdSyLZEv9DDXogskJ
    http-conduit-2.3.9.1-JuSKcL2x7gvHrvi4XVCcUw
    http-types-0.12.4-BfnwqLIFvgHNb88uBZwW9
    multimap-1.2.1-4W8aWHvVl9g78Tpaptjwyw parsec-3.1.16.1
    process-1.6.19.0 rate-limit-1.4.3-6ydvOkN3EwQLZ5xS3sVlHp
    regex-compat-0.95.2.2-DwcD5qxZGc67j8Pwq49pag
    safe-0.3.21-Hishw766JFf9X5XLYDU9sV
    scotty-0.22-CXZt2T9pP1l2kK8712kzeM
    split-0.2.5-Bi3HfS9SciuGUuXE3PHa4h
    status-notifier-item-0.3.2.0-9w0XVnYLwOk6c7oRd0Nrzd stm-2.5.1.0
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-8XUEctZKps57K6Zw5siYoh
    time-units-1.0.0-5DRkw9RXZDICp7PYN09sTv transformers-0.6.1.0
    tuple-0.3.0.2-B7ky6gKwC1XLkXDrsr2pVq unix-2.8.4.0
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    xdg-basedir-0.2.2-DLaKUfv1JJAFBfkP0BUklH
    xdg-desktop-entry-0.1.1.4-L5OBetT0mJNKiXH9Utjrhu
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    xml-helpers-1.0.0-4qhWXJoUbtX94cToL5WE9g
    xmonad-0.18.0-2RDNSVx2n008HYbUdbIX15

haddock-interfaces:     /usr/share/doc/taffybar/html/taffybar.haddock
haddock-html:           /usr/share/doc/taffybar/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-taffybar-z-testlib
version:              4.1.0
package-name:         taffybar
lib-name:             testlib
id:                   taffybar-4.1.0-6U7sH51DimfBpv0uvQclPw-testlib
key:                  taffybar-4.1.0-6U7sH51DimfBpv0uvQclPw-testlib
license:              BSD-3-Clause
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             http://github.com/taffybar/taffybar
synopsis:             A desktop bar similar to xmobar, but with more GUI
category:             System
abi:                  35854998c7930d8dfa588f61b2876985
exposed-modules:
    System.Taffybar.Test.DBusSpec System.Taffybar.Test.UtilSpec
    System.Taffybar.Test.XvfbSpec TestLibSpec

import-dirs:          /usr/lib/ghc-9.6.6/site-local/taffybar-4.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/taffybar-4.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/taffybar-4.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/taffybar
hs-libraries:         HStaffybar-4.1.0-6U7sH51DimfBpv0uvQclPw-testlib
depends:
    QuickCheck-2.15.0.1-Erpv4AOLtST7sTBBKJurVZ
    attoparsec-0.14.4-9CcJCC4ORykBmnSiMZ6uwP base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    dbus-1.3.3-B29sEISa9vRKO9bSWo5TvW
    extra-1.7.16-EBdVSHGIn1MFifI9eiYLtn filepath-1.4.300.1
    hslogger-1.3.2.0-E6C8jEKjAdBKKjE0uqQrQ7
    hspec-2.11.5-Dau5AYLA4Sc5yG8ujPk7qp
    taffybar-4.1.0-B8RMwXYabgTJIrANlcaFPo text-2.0.2
    typed-process-0.2.13.0-3njdao0UBftC0M0fDGFJH2 unix-2.8.4.0
    unliftio-0.2.25.1-Jl71xZxtWw8GvgwO5TEzPz
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:   /usr/share/doc/taffybar/html/taffybar.haddock
haddock-html:         /usr/share/doc/taffybar/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

